@@ -5,6 +5,9 @@
 
 import re
 
+from azure.cli.command_modules.acs._consts import (
+    CONST_DEFAULT_NODE_OS_TYPE
+)
 from azure.cli.command_modules.acs.azurecontainerstorage._consts import (
     CONST_ACSTOR_ALL,
     CONST_ACSTOR_IO_ENGINE_LABEL_KEY,
@@ -38,7 +41,7 @@ elastic_san_supported_skus = [
 logger = get_logger(__name__)
 
 
-def validate_disable_azure_container_storage_params(
+def validate_disable_azure_container_storage_params(  # pylint: disable=too-many-branches
     storage_pool_type,
     storage_pool_name,
     storage_pool_sku,
@@ -50,6 +53,8 @@ def validate_disable_azure_container_storage_params(
     is_elasticSan_enabled,
     is_ephemeralDisk_localssd_enabled,
     is_ephemeralDisk_nvme_enabled,
+    ephemeral_disk_volume_type,
+    ephemeral_disk_nvme_perf_tier,
 ):
     if not is_extension_installed:
         raise InvalidArgumentValueError(
@@ -75,6 +80,18 @@ def validate_disable_azure_container_storage_params(
             'when --disable-azure-container-storage is set.'
         )
 
+    if ephemeral_disk_volume_type is not None:
+        raise MutuallyExclusiveArgumentError(
+            'Conflicting flags. Cannot define --ephemeral-disk-volume-type value '
+            'when --disable-azure-container-storage is set.'
+        )
+
+    if ephemeral_disk_nvme_perf_tier is not None:
+        raise MutuallyExclusiveArgumentError(
+            'Conflicting flags. Cannot define --ephemeral-disk-nvme-perf-tier value '
+            'when --disable-azure-container-storage is set.'
+        )
+
     if storage_pool_option is not None:
         if storage_pool_type != CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK:
             raise ArgumentUsageError(
@@ -155,7 +172,7 @@ def validate_disable_azure_container_storage_params(
             )
 
 
-def validate_enable_azure_container_storage_params(
+def validate_enable_azure_container_storage_params(  # pylint: disable=too-many-locals,too-many-branches
     storage_pool_type,
     storage_pool_name,
     storage_pool_sku,
@@ -168,6 +185,10 @@ def validate_enable_azure_container_storage_params(
     is_elasticSan_enabled,
     is_ephemeralDisk_localssd_enabled,
     is_ephemeralDisk_nvme_enabled,
+    ephemeral_disk_volume_type,
+    ephemeral_disk_nvme_perf_tier,
+    existing_ephemeral_disk_volume_type,
+    existing_ephemeral_disk_nvme_perf_tier,
 ):
     if storage_pool_name is not None:
         pattern = r'[a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*'
@@ -195,11 +216,124 @@ def validate_enable_azure_container_storage_params(
             )
 
     if storage_pool_type == CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK:
-        if storage_pool_option is None:
-            raise RequiredArgumentMissingError(
-                'Value of --storage-pool-option must be defined when '
-                '--enable-azure-container-storage is set to ephemeralDisk.'
-            )
+        if ephemeral_disk_volume_type is None and ephemeral_disk_nvme_perf_tier is None:
+            if storage_pool_option is None:
+                raise RequiredArgumentMissingError(
+                    'Value of --storage-pool-option must be defined when '
+                    '--enable-azure-container-storage is set to ephemeralDisk.'
+                )
+        else:
+            required_type_installed_for_disk_vol_type = False
+            required_type_installed_for_nvme_perf_tier = False
+
+            if ephemeral_disk_volume_type is not None:
+                required_type_installed_for_disk_vol_type = is_extension_installed and \
+                    (is_ephemeralDisk_localssd_enabled or is_ephemeralDisk_nvme_enabled)
+
+            if ephemeral_disk_nvme_perf_tier is not None:
+                required_type_installed_for_nvme_perf_tier = is_extension_installed and \
+                    is_ephemeralDisk_nvme_enabled
+
+            if storage_pool_option is None:
+                option_needed_by_dependent_params = []
+                supported_option_needed = ''
+                if ephemeral_disk_volume_type is not None and not required_type_installed_for_disk_vol_type:
+                    option_needed_by_dependent_params.append('--ephemeral-disk-volume-type')
+                    supported_option_needed = f'{CONST_STORAGE_POOL_OPTION_NVME} or {CONST_STORAGE_POOL_OPTION_SSD}'
+                if ephemeral_disk_nvme_perf_tier is not None and not required_type_installed_for_nvme_perf_tier:
+                    option_needed_by_dependent_params.append('--ephemeral-disk-nvme-perf-tier')
+                    supported_option_needed = {CONST_STORAGE_POOL_OPTION_NVME}
+
+                if len(option_needed_by_dependent_params) > 0:
+                    params_requiring_options = ', '.join(option_needed_by_dependent_params)
+                    raise ArgumentUsageError(
+                        f'Cannot set {params_requiring_options} along with --enable-azure-container-storage '
+                        f'when storage pool type: {CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK} option: '
+                        f'{supported_option_needed} is not enabled for Azure Container Storage. '
+                        'Enable the option using --storage-pool-option.'
+                    )
+            else:
+                if ephemeral_disk_nvme_perf_tier is not None and not required_type_installed_for_nvme_perf_tier and \
+                   storage_pool_option != CONST_STORAGE_POOL_OPTION_NVME:
+                    raise ArgumentUsageError(
+                        'Cannot set --ephemeral-disk-nvme-perf-tier along with --enable-azure-container-storage '
+                        f'when storage pool type: {CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK} option: '
+                        f'{CONST_STORAGE_POOL_OPTION_NVME} is not enabled for Azure Container Storage. '
+                        'Enable the option using --storage-pool-option.'
+                    )
+
+            if (storage_pool_name is not None or storage_pool_sku is not None or
+               storage_pool_size is not None or nodepool_list is not None):
+                # pylint: disable=too-many-boolean-expressions
+                if (ephemeral_disk_volume_type is not None and
+                    required_type_installed_for_disk_vol_type and ephemeral_disk_nvme_perf_tier is None) or \
+                    (ephemeral_disk_volume_type is None and
+                     ephemeral_disk_nvme_perf_tier is not None and required_type_installed_for_nvme_perf_tier) or \
+                    (ephemeral_disk_volume_type is not None and required_type_installed_for_disk_vol_type and
+                     ephemeral_disk_nvme_perf_tier is not None and required_type_installed_for_nvme_perf_tier):
+                    enabled_options_arr = []
+                    if is_ephemeralDisk_nvme_enabled:
+                        enabled_options_arr.append(CONST_STORAGE_POOL_OPTION_NVME)
+                    if is_ephemeralDisk_localssd_enabled:
+                        enabled_options_arr.append(CONST_STORAGE_POOL_OPTION_SSD)
+                    enabled_options = ', '.join(enabled_options_arr)
+
+                    params_defined_arr = []
+                    if storage_pool_size is not None:
+                        params_defined_arr.append('--storage-pool-size')
+                    if storage_pool_sku is not None:
+                        params_defined_arr.append('--storage-pool-sku')
+                    if storage_pool_name is not None:
+                        params_defined_arr.append('--storage-pool-name')
+                    if nodepool_list is not None:
+                        params_defined_arr.append('--azure-container-storage-nodepools')
+                    params = ', '.join(params_defined_arr)
+
+                    flags_defined_arr = []
+                    if ephemeral_disk_volume_type is not None:
+                        flags_defined_arr.append('--ephemeral-disk-volume-type')
+                    if ephemeral_disk_nvme_perf_tier is not None:
+                        flags_defined_arr.append('--ephemeral-disk-nvme-perf-tier')
+
+                    flags_defined = ', '.join(flags_defined_arr)
+
+                    raise ArgumentUsageError(
+                        f'Cannot set {params} for creation of a new storage pool while setting value for '
+                        f'{flags_defined} since {CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK} storage pool type is '
+                        f'already enabled for storage pool option {enabled_options}.'
+                    )
+            else:
+                if required_type_installed_for_disk_vol_type and \
+                   ephemeral_disk_volume_type is not None and \
+                   ephemeral_disk_nvme_perf_tier is None and \
+                   existing_ephemeral_disk_volume_type.lower() == ephemeral_disk_volume_type.lower():
+                    raise InvalidArgumentValueError(
+                        'Azure Container Storage is already configured with --ephemeral-disk-volume-type '
+                        f'value set to {existing_ephemeral_disk_volume_type}.'
+                    )
+
+                if required_type_installed_for_nvme_perf_tier and \
+                   ephemeral_disk_nvme_perf_tier is not None and \
+                   ephemeral_disk_volume_type is None and \
+                   existing_ephemeral_disk_nvme_perf_tier.lower() == ephemeral_disk_nvme_perf_tier.lower():
+                    raise InvalidArgumentValueError(
+                        'Azure Container Storage is already configured with --ephemeral-disk-nvme-perf-tier '
+                        f'value set to {existing_ephemeral_disk_nvme_perf_tier}.'
+                    )
+
+                # pylint: disable=too-many-boolean-expressions
+                if required_type_installed_for_disk_vol_type and \
+                   ephemeral_disk_volume_type is not None and \
+                   existing_ephemeral_disk_volume_type.lower() == ephemeral_disk_volume_type.lower() and \
+                   required_type_installed_for_nvme_perf_tier and \
+                   ephemeral_disk_nvme_perf_tier is not None and \
+                   existing_ephemeral_disk_nvme_perf_tier.lower() == ephemeral_disk_nvme_perf_tier.lower():
+                    raise InvalidArgumentValueError(
+                        'Azure Container Storage is already configured with --ephemeral-disk-volume-type '
+                        f'value set to {existing_ephemeral_disk_volume_type} and --ephemeral-disk-nvme-perf-tier '
+                        f'value set to {existing_ephemeral_disk_nvme_perf_tier}.'
+                    )
+
         if storage_pool_option == CONST_ACSTOR_ALL:
             raise InvalidArgumentValueError(
                 f'Cannot set --storage-pool-option value as {CONST_ACSTOR_ALL} '
@@ -211,6 +345,16 @@ def validate_enable_azure_container_storage_params(
                 'Cannot set --storage-pool-option when --enable-azure-container-storage is not ephemeralDisk.'
             )
 
+        if ephemeral_disk_volume_type is not None:
+            raise ArgumentUsageError(
+                'Cannot set --ephemeral-disk-volume-type when --enable-azure-container-storage is not ephemeralDisk.'
+            )
+
+        if ephemeral_disk_nvme_perf_tier is not None:
+            raise ArgumentUsageError(
+                'Cannot set --ephemeral-disk-nvme-perf-tier when --enable-azure-container-storage is not ephemeralDisk.'
+            )
+
     _validate_storage_pool_size(storage_pool_size, storage_pool_type)
 
     _validate_nodepools(
@@ -232,9 +376,11 @@ def validate_enable_azure_container_storage_params(
                 f'{storage_pool_type} in the cluster.'
             )
 
+        # pylint: disable=too-many-boolean-expressions
         if storage_pool_type == CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK and \
            ((is_ephemeralDisk_nvme_enabled and
-            storage_pool_option == CONST_STORAGE_POOL_OPTION_NVME) or
+            storage_pool_option == CONST_STORAGE_POOL_OPTION_NVME and
+            ephemeral_disk_nvme_perf_tier is None) or
             (is_ephemeralDisk_localssd_enabled and
                 storage_pool_option == CONST_STORAGE_POOL_OPTION_SSD)):
             ephemeral_disk_type_installed = CONST_STORAGE_POOL_OPTION_SSD if \
@@ -280,7 +426,7 @@ def _validate_storage_pool_size(storage_pool_size, storage_pool_type):
             )
 
 
-def _validate_nodepools(
+def _validate_nodepools(  # pylint: disable=too-many-branches
     nodepool_list,
     agentpool_details,
     storage_pool_type,
@@ -301,12 +447,13 @@ def _validate_nodepools(
                 'in a cluster where Azure Container Storage is already installed.'
             )
 
-        for agentpool in agentpool_details:
-            node_labels = agentpool.get("node_labels")
-            if node_labels is not None and \
-               node_labels.get(CONST_ACSTOR_IO_ENGINE_LABEL_KEY) is not None:
-                nodepool_name = agentpool.get("name")
-                nodepool_arr.append(nodepool_name)
+        if agentpool_details is not None:
+            for agentpool in agentpool_details:
+                node_labels = agentpool.get("node_labels")
+                if node_labels is not None and \
+                   node_labels.get(CONST_ACSTOR_IO_ENGINE_LABEL_KEY) is not None:
+                    nodepool_name = agentpool.get("name")
+                    nodepool_arr.append(nodepool_name)
 
         if len(nodepool_arr) == 0:
             raise ArgumentUsageError(
@@ -322,14 +469,43 @@ def _validate_nodepools(
             'from the node pool and use node pools which has nodes with 4 or more cores and try again.'
         )
     else:
-        _validate_nodepool_names(nodepool_list, agentpool_details)
+        agentpool_names = []
+        if agentpool_details is not None:
+            for details in agentpool_details:
+                agentpool_names.append(details.get("name"))
+        if not nodepool_list:
+            agentpool_names_str = ', '.join(agentpool_names)
+            raise RequiredArgumentMissingError(
+                'Multiple node pools present. Please define the node pools on which you want '
+                'to enable Azure Container Storage using --azure-container-storage-nodepools.'
+                f'\nNode pools available in the cluster are: {agentpool_names_str}.'
+                '\nAborting Azure Container Storage operation.'
+            )
+        _validate_nodepool_names(nodepool_list, agentpool_names)
         nodepool_arr = nodepool_list.split(',')
 
     nvme_nodepool_found = False
+    available_node_count = 0
     for nodepool in nodepool_arr:
         for agentpool in agentpool_details:
             pool_name = agentpool.get("name")
             if nodepool == pool_name:
+                os_type = agentpool.get("os_type")
+                if os_type is not None and os_type.lower() != CONST_DEFAULT_NODE_OS_TYPE.lower():
+                    raise InvalidArgumentValueError(
+                        f'Azure Container Storage can be enabled only on {CONST_DEFAULT_NODE_OS_TYPE} nodepools. '
+                        f'Node pool: {pool_name}, os type: {os_type} does not meet the criteria.'
+                    )
+                mode = agentpool.get("mode")
+                node_taints = agentpool.get("node_taints")
+                if mode is not None and mode.lower() == "system" and node_taints is not None:
+                    critical_taint = "CriticalAddonsOnly=true:NoSchedule"
+                    if critical_taint.casefold() in (taint.casefold() for taint in node_taints):
+                        raise InvalidArgumentValueError(
+                            f'Unable to install Azure Container Storage on system nodepool: {pool_name} '
+                            f'since it has a taint {critical_taint}. Remove the taint from the node pool '
+                            'and retry the Azure Container Storage operation.'
+                        )
                 vm_size = agentpool.get("vm_size")
                 if vm_size is not None:
                     cpu_value = get_cores_from_sku(vm_size)
@@ -343,6 +519,15 @@ def _validate_nodepools(
                     if vm_size.lower().startswith('standard_l'):
                         nvme_nodepool_found = True
 
+                node_count = agentpool.get("count")
+                if node_count is not None:
+                    available_node_count = available_node_count + node_count
+
+    if available_node_count < 3:
+        raise UnknownError(
+            'Insufficient nodes present. Azure Container Storage requires atleast 3 nodes to be enabled.'
+        )
+
     if storage_pool_type == CONST_STORAGE_POOL_TYPE_EPHEMERAL_DISK and \
        storage_pool_option == CONST_STORAGE_POOL_OPTION_NVME and \
        not nvme_nodepool_found:
@@ -355,7 +540,7 @@ def _validate_nodepools(
 # _validate_nodepool_names validates that the nodepool_list is a comma separated
 # string consisting of valid nodepool names i.e. a lower alphanumeric
 # characters and the first character should be lowercase letter.
-def _validate_nodepool_names(nodepool_names, agentpool_details):
+def _validate_nodepool_names(nodepool_names, agentpool_names):
     pattern = r'^[a-z][a-z0-9]*(?:,[a-z][a-z0-9]*)*$'
     if re.fullmatch(pattern, nodepool_names) is None:
         raise InvalidArgumentValueError(
@@ -365,10 +550,6 @@ def _validate_nodepool_names(nodepool_names, agentpool_details):
             "alphanumeric characters and must begin with a lowercase letter."
         )
 
-    agentpool_names = []
-    for details in agentpool_details:
-        agentpool_names.append(details.get("name"))
-
     nodepool_list = nodepool_names.split(',')
     for nodepool in nodepool_list:
         if nodepool not in agentpool_names:
