@@ -315,6 +315,8 @@ examples:
 helps['mysql flexible-server update'] = """
 type: command
 short-summary: Update a flexible server.
+long-summary: >
+  [!WARNING] Enabling High-availability may result in a short downtime for the server based on your server configuration.
 examples:
   - name: Update a flexible server's sku, using local context for server and resource group.
     text: az mysql flexible-server update --sku-name Standard_D4ds_v4 --tier GeneralPurpose
@@ -436,6 +438,15 @@ examples:
     text: az mysql flexible-server restart --resource-group testGroup --name testserver --failover Forced
 """
 
+helps['mysql flexible-server detach-vnet'] = """
+type: command
+short-summary: Detach vnet for a flexible server.
+examples:
+  - name: Detach vnet for a flexible server with public access disabled.
+    text: az mysql flexible-server detach-vnet --resource-group testGroup --name testserver --public-network-access Disabled
+    crafted: true
+"""
+
 helps['mysql flexible-server wait'] = """
 type: command
 short-summary: Wait for the flexible server to satisfy certain conditions.
