@@ -11,7 +11,7 @@ from azure.cli.core.commands.parameters import tags_type, get_location_type, get
 from azure.cli.command_modules.mysql.action import AddArgs
 from azure.cli.command_modules.mysql.random.generate import generate_username
 from azure.cli.command_modules.mysql._validators import public_access_validator, maintenance_window_validator, ip_address_validator, \
-    firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities
+    firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities, validate_action_name, validate_branch
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 from ._util import get_current_time
 from argcomplete.completers import FilesCompleter
@@ -439,6 +439,10 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     with self.argument_context('mysql flexible-server list-skus') as c:
         c.argument('location', arg_type=get_location_type(self.cli_ctx))
 
+    with self.argument_context('mysql flexible-server detach-vnet') as c:
+        c.argument('public_network_access', options_list=['--public-network-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access after vnet detach. ')
+        c.argument('yes', arg_type=yes_arg_type)
+
     # flexible-server parameter
     for scope in ['list', 'set', 'show', 'set-batch']:
         argument_context_string = 'mysql flexible-server parameter {}'.format(scope)
@@ -543,8 +547,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('allow_push', default=False, options_list=['--allow-push'], arg_type=get_three_state_flag(), help='Push the action yml file to the remote repository. The changes will be pushed to origin repository, speicified branch or current branch if not specified.')
 
     with self.argument_context('mysql flexible-server deploy run') as c:
-        c.argument('action_name', options_list=['--action-name'], help='The name of the github action')
-        c.argument('branch', options_list=['--branch'], help='The name of the branch you want upload github action file. The default will be your current branch.')
+        c.argument('action_name', options_list=['--action-name'], help='The name of the github action', validator=validate_action_name)
+        c.argument('branch', options_list=['--branch'], help='The name of the branch you want upload github action file. The default will be your current branch.', validator=validate_branch)
 
     with self.argument_context('mysql flexible-server server-logs download') as c:
         c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
