@@ -315,6 +315,11 @@ class VolumeCreate(_VolumeCreate):
             minimum=100
         )
 
+        args_schema.coolness_period._fmt = AAZIntArgFormat(
+            maximum=183,
+            minimum=2,
+        )
+
         # The API does only support setting Basic and Standard
         args_schema.network_features.enum = AAZArgEnum({"Basic": "Basic", "Standard": "Standard"}, case_sensitive=False)
 
@@ -439,6 +444,11 @@ class VolumeUpdate(_VolumeUpdate):
             minimum=100,
         )
 
+        args_schema.coolness_period._fmt = AAZIntArgFormat(
+            maximum=183,
+            minimum=2,
+        )
+
         return args_schema
 
     def pre_operations(self):
