@@ -1058,6 +1058,12 @@ class CrossRegionLoadBalancerAddressPoolCreate(_LBAddressPoolCreate):
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
 
+        args_schema.admin_state = AAZStrArg(
+            options=["--admin-state"],
+            arg_group="Properties",
+            help="Default administrative state to backend addresses in `--backend-addresses`.",
+        )
+        args_schema.admin_state.enum = args_schema.backend_addresses.Element.admin_state.enum
         # not support name, the frontend id should belong to a regional load balance
         args_schema.backend_addresses.Element.frontend_ip_address._fmt = AAZResourceIdArgFormat(
             template="/subscriptions/{subscription}/resourceGroups/{resource_group}/providers/Microsoft.Network/loadBalancers/{}/frontendIPConfigurations/{}"
@@ -1066,12 +1072,19 @@ class CrossRegionLoadBalancerAddressPoolCreate(_LBAddressPoolCreate):
         args_schema.backend_addresses.Element.frontend_ip_address._required = True
 
         args_schema.tunnel_interfaces._registered = False
-        args_schema.backend_addresses.Element.admin_state._registered = False
         args_schema.backend_addresses.Element.ip_address._registered = False
         args_schema.backend_addresses.Element.subnet._registered = False
         args_schema.backend_addresses.Element.virtual_network._registered = False
         return args_schema
 
+    def pre_operations(self):
+        args = self.ctx.args
+        if has_value(args.backend_addresses):
+            for backend_address in args.backend_addresses:
+                if not has_value(backend_address.admin_state) and has_value(args.admin_state):
+                    # use the command level argument --admin-state
+                    backend_address.admin_state = args.admin_state
+
 
 @register_command("network cross-region-lb address-pool update")
 class CrossRegionLoadBalancerAddressPoolUpdate(_LBAddressPoolUpdate):
@@ -1091,20 +1104,34 @@ class CrossRegionLoadBalancerAddressPoolUpdate(_LBAddressPoolUpdate):
     def _build_arguments_schema(cls, *args, **kwargs):
         args_schema = super()._build_arguments_schema(*args, **kwargs)
 
+        args_schema.admin_state = AAZStrArg(
+            options=["--admin-state"],
+            arg_group="Properties",
+            help="Default administrative state to backend addresses in `--backend-addresses`.",
+        )
+        args_schema.admin_state.enum = args_schema.backend_addresses.Element.admin_state.enum
         # not support name, the frontend id should belong to a regional load balance
         args_schema.backend_addresses.Element.frontend_ip_address._fmt = AAZResourceIdArgFormat(
             template="/subscriptions/{subscription}/resourceGroups/{resource_group}/providers/Microsoft.Network/loadBalancers/{}/frontendIPConfigurations/{}"
         )
         args_schema.backend_addresses.Element.name._nullable = False
         args_schema.backend_addresses.Element.frontend_ip_address._nullable = False
+        args_schema.backend_addresses.Element.admin_state._nullable = False
 
         args_schema.tunnel_interfaces._registered = False
-        args_schema.backend_addresses.Element.admin_state._registered = False
         args_schema.backend_addresses.Element.ip_address._registered = False
         args_schema.backend_addresses.Element.subnet._registered = False
         args_schema.backend_addresses.Element.virtual_network._registered = False
         return args_schema
 
+    def pre_operations(self):
+        args = self.ctx.args
+        if has_value(args.backend_addresses):
+            for backend_address in args.backend_addresses:
+                if not has_value(backend_address.admin_state) and has_value(args.admin_state):
+                    # use the command level argument --admin-state
+                    backend_address.admin_state = args.admin_state
+
 
 @register_command("network cross-region-lb address-pool show")
 class CrossRegionLoadBalancerAddressPoolShow(_LBAddressPoolShow):
@@ -1149,7 +1176,6 @@ class CrossRegionLoadBalancerAddressPoolAddressAdd(_LBAddressPoolAddressAdd):
         )
 
         args_schema.frontend_ip_address._required = True
-        args_schema.admin_state._registered = False
         args_schema.ip_address._registered = False
         args_schema.subnet._registered = False
         args_schema.virtual_network._registered = False
@@ -1184,7 +1210,6 @@ class CrossRegionLoadBalancerAddressPoolAddressUpdate(_LBAddressPoolAddressUpdat
         )
 
         args_schema.frontend_ip_address._nullable = False
-        args_schema.admin_state._registered = False
         args_schema.ip_address._registered = False
         args_schema.subnet._registered = False
         args_schema.virtual_network._registered = False
