@@ -57,7 +57,10 @@ def flexible_server_create(cmd, client,
                            high_availability=None, zone=None, standby_availability_zone=None,
                            geo_redundant_backup=None, byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None,
                            active_directory_auth=None, password_auth=None, auto_grow=None, performance_tier=None,
-                           storage_type=None, iops=None, throughput=None, yes=False):
+                           storage_type=None, iops=None, throughput=None, create_default_db='Enabled', yes=False):
+
+    # Warning for upcoming breaking change to default value of pg version
+    logger.warning('In the next release, the default value for the PostgreSQL server major version will be updated to 16')
 
     # Generate missing parameters
     location, resource_group_name, server_name = generate_missing_parameters(cmd, location, resource_group_name,
@@ -152,9 +155,9 @@ def flexible_server_create(cmd, client,
         firewall_id = create_firewall_rule(db_context, cmd, resource_group_name, server_name, start_ip, end_ip)
 
     # Create mysql database if it does not exist
-    if database_name is None:
-        database_name = DEFAULT_DB_NAME
-    _create_database(db_context, cmd, resource_group_name, server_name, database_name)
+    if database_name is not None or (create_default_db and create_default_db.lower() == 'enabled'):
+        db_name = database_name if database_name else DEFAULT_DB_NAME
+        _create_database(db_context, cmd, resource_group_name, server_name, db_name)
 
     user = server_result.administrator_login
     server_id = server_result.id
@@ -183,7 +186,7 @@ def flexible_server_restore(cmd, client,
                             source_server, restore_point_in_time=None, zone=None, no_wait=False,
                             subnet=None, subnet_address_prefix=None, vnet=None, vnet_address_prefix=None,
                             private_dns_zone_arguments=None, geo_redundant_backup=None,
-                            byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None, yes=False):
+                            byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None, storage_type=None, yes=False):
 
     server_name = server_name.lower()
 
@@ -200,6 +203,8 @@ def flexible_server_restore(cmd, client,
     else:
         source_server_id = source_server
 
+    instance = client.get(resource_group_name, source_server)
+
     restore_point_in_time = validate_and_format_restore_point_in_time(restore_point_in_time)
 
     try:
@@ -220,12 +225,15 @@ def flexible_server_restore(cmd, client,
 
         pg_byok_validator(byok_identity, byok_key, backup_byok_identity, backup_byok_key, geo_redundant_backup)
 
+        storage = postgresql_flexibleservers.models.Storage(type=storage_type if instance.storage.type != "PremiumV2_LRS" else None)
+
         parameters = postgresql_flexibleservers.models.Server(
             location=location,
             point_in_time_utc=restore_point_in_time,
             source_server_resource_id=source_server_id,  # this should be the source server name, not id
             create_mode="PointInTimeRestore",
-            availability_zone=zone
+            availability_zone=zone,
+            storage=storage
         )
 
         if source_server_object.network.public_network_access == 'Disabled' and any((vnet, subnet)):
@@ -270,6 +278,7 @@ def flexible_server_update_custom_func(cmd, client, instance,
                                        backup_byok_identity=None, backup_byok_key=None,
                                        active_directory_auth=None, password_auth=None,
                                        private_dns_zone_arguments=None,
+                                       public_access=None,
                                        tags=None,
                                        auto_grow=None,
                                        performance_tier=None,
@@ -311,6 +320,9 @@ def flexible_server_update_custom_func(cmd, client, instance,
     resource_group_name = server_id_parts['resource_group']
     server_name = server_id_parts['name']
 
+    if public_access:
+        instance.network.public_network_access = public_access
+
     if private_dns_zone_arguments:
         private_dns_zone_id = prepare_private_dns_zone(db_context,
                                                        resource_group_name,
@@ -351,13 +363,14 @@ def flexible_server_update_custom_func(cmd, client, instance,
     if backup_retention:
         instance.backup.backup_retention_days = backup_retention
 
-    if maintenance_window and maintenance_window.lower() == "disabled":
-        # if disabled is pass in reset to default values
-        day_of_week = start_hour = start_minute = 0
-        custom_window = "Disabled"
-    elif maintenance_window:
-        day_of_week, start_hour, start_minute = parse_maintenance_window(maintenance_window)
-        custom_window = "Enabled"
+    if maintenance_window:
+        if maintenance_window.lower() == "disabled":
+            # if disabled is pass in reset to default values
+            day_of_week = start_hour = start_minute = 0
+            custom_window = "Disabled"
+        else:
+            day_of_week, start_hour, start_minute = parse_maintenance_window(maintenance_window)
+            custom_window = "Enabled"
 
         # set values - if maintenance_window when is None when created then create a new object
         instance.maintenance_window.day_of_week = day_of_week
@@ -1089,7 +1102,7 @@ def flexible_server_list_log_files_with_filter(client, resource_group_name, serv
 
 
 def migration_create_func(cmd, client, resource_group_name, server_name, properties, migration_mode="offline",
-                          migration_name=None, migration_option=None, tags=None, location=None, migrationInstanceResourceId=None):
+                          migration_name=None, migration_option=None, tags=None, location=None):
 
     logging_name = 'PostgreSQL'
     subscription_id = get_subscription_id(cmd.cli_ctx)
@@ -1117,11 +1130,8 @@ def migration_create_func(cmd, client, resource_group_name, server_name, propert
         # Use default migration_option as 'ValidateAndMigrate'
         migration_option = "ValidateAndMigrate"
 
-    if migrationInstanceResourceId is not None:
-        validate_migration_runtime_server(cmd, migrationInstanceResourceId, resource_group_name, server_name)
-
-    return _create_migration(logging_name, client, subscription_id, resource_group_name, server_name, migration_name,
-                             migration_mode, migration_option, migration_parameters, tags, location, migrationInstanceResourceId)
+    return _create_migration(cmd, logging_name, client, subscription_id, resource_group_name, server_name, migration_name,
+                             migration_mode, migration_option, migration_parameters, tags, location)
 
 
 def migration_show_func(cmd, client, resource_group_name, server_name, migration_name):
@@ -1397,11 +1407,15 @@ def _get_pg_replica_zone(availabilityZones, sourceServerZone, replicaZone):
     return pg_replica_zone
 
 
-def _create_migration(logging_name, client, subscription_id, resource_group_name, target_db_server_name,
-                      migration_name, migration_mode, migration_option, parameters, tags, location, migrationInstanceResourceId):
+def _create_migration(cmd, logging_name, client, subscription_id, resource_group_name, target_db_server_name,
+                      migration_name, migration_mode, migration_option, parameters, tags, location):
+
+    parameter_keys = list(parameters.keys())
+    migrationInstanceResourceId = get_case_insensitive_key_value("MigrationRuntimeResourceId", parameter_keys, parameters)
+    if migrationInstanceResourceId is not None:
+        validate_migration_runtime_server(cmd, migrationInstanceResourceId, resource_group_name, target_db_server_name)
 
     logger.warning('Creating %s Migration for server \'%s\' in group \'%s\' and subscription \'%s\'...', logging_name, target_db_server_name, resource_group_name, subscription_id)
-    parameter_keys = list(parameters.keys())
     secret_parameter_dictionary = get_case_insensitive_key_value("SecretParameters", parameter_keys, parameters)
     secret_parameter_keys = list(secret_parameter_dictionary.keys())
     admin_credentials_dictionary = get_case_insensitive_key_value("AdminCredentials", secret_parameter_keys, secret_parameter_dictionary)
@@ -1427,7 +1441,8 @@ def _create_migration(logging_name, client, subscription_id, resource_group_name
         overwrite_dbs_in_target=get_enum_value_true_false(get_case_insensitive_key_value("OverwriteDbsInTarget", parameter_keys, parameters), "OverwriteDbsInTarget"),
         source_type=source_type,
         migration_option=migration_option,
-        ssl_mode=ssl_mode)
+        ssl_mode=ssl_mode,
+        migration_instance_resource_id=migrationInstanceResourceId)
 
     return client.create(subscription_id, resource_group_name, target_db_server_name, migration_name, migration_parameters)
 
