@@ -219,10 +219,19 @@ for source in SOURCE_RESOURCES:
 
         # auth info params
         auth_types = SUPPORTED_AUTH_TYPE.get(source).get(target)
-        auth_params = get_auth_info_params(auth_types[0])
+        if auth_types[0] == AUTH_TYPE.WorkloadIdentity:
+            if target is RESOURCE.KeyVault:
+                auth_params = '--enable-csi'
+            else:
+                auth_params = get_auth_info_params(AUTH_TYPE.SecretAuto)
+        else:
+            auth_params = get_auth_info_params(auth_types[0])
 
         # auth info params in help message
-        secret_param = '''
+        secret_param = ''
+        if AUTH_TYPE.Secret in auth_types:
+            if source.value != RESOURCE.KubernetesCluster.value:
+                secret_param = '''
             - name: --secret
               short-summary: The secret auth info
               long-summary: |
@@ -234,7 +243,19 @@ for source in SOURCE_RESOURCES:
                 secret  : One of <secret, secret-uri, secret-name> is required. Password or account key for secret auth.
                 secret-uri  : One of <secret, secret-uri, secret-name> is required. Keyvault secret uri which stores password.
                 secret-name : One of <secret, secret-uri, secret-name> is required. Keyvault secret name which stores password. It's for AKS only.
-        ''' if AUTH_TYPE.Secret in auth_types else ''
+        '''
+            else:
+                secret_param = '''
+            - name: --secret
+              short-summary: The secret auth info
+              long-summary: |
+                Usage: --secret name=XX secret=XX
+                       --secret name=XX secret-name=XX
+
+                name    : Required. Username or account name for secret auth.
+                secret  : One of <secret, secret-uri, secret-name> is required. Password or account key for secret auth.
+                secret-name : One of <secret, secret-uri, secret-name> is required. Keyvault secret name which stores password. It's for AKS only.
+        '''
         secret_auto_param = '''
             - name: --secret
               short-summary: The secret auth info
@@ -270,6 +291,15 @@ for source in SOURCE_RESOURCES:
                 client-id      : Required. Client id of the user assigned identity.
                 subs-id        : Required. Subscription id of the user assigned identity.
         ''' if AUTH_TYPE.UserIdentity in auth_types else ''
+        workload_identity_param = '''
+            - name: --workload-identity
+              short-summary: The user-assigned managed identity used to create workload identity federation.
+              long-summary: |
+                Usage: --workload-identity <user-identity-resource-id>
+
+                user-identity-resource-id: Required. The resource id of the user assigned identity.
+                Please DO NOT use AKS control plane identity and kubelet identity which is not supported by federated identity credential.
+        ''' if AUTH_TYPE.WorkloadIdentity in auth_types else ''
         service_principal_param = '''
             - name: --service-principal
               short-summary: The service principal auth info
@@ -307,6 +337,18 @@ for source in SOURCE_RESOURCES:
             auth_params=auth_params,
             source_display_name=source_display_name) if source is RESOURCE.WebApp else ''
 
+        aks_keyvault_example = '''
+            - name: Create a connection between {source_display_name} and {target} using secret store csi driver
+              text: |-
+                     az {source} connection create {target} {source_params} {target_params} --enable-csi
+        '''.format(
+            source=source.value,
+            target=target.value,
+            source_params=source_params,
+            target_params=target_params,
+            source_display_name=source_display_name
+        ) if source is RESOURCE.KubernetesCluster and target is RESOURCE.KeyVault else ''
+
         helps['{source} connection create {target}'.format(source=source.value, target=target.value)] = """
           type: command
           short-summary: Create a {source_display_name} connection to {target}.
@@ -315,6 +357,7 @@ for source in SOURCE_RESOURCES:
             {secret_auto_param}
             {system_identity_param}
             {user_identity_param}
+            {workload_identity_param}
             {service_principal_param}
           examples:
             - name: Create a connection between {source_display_name} and {target} interactively
@@ -337,6 +380,7 @@ for source in SOURCE_RESOURCES:
             secret_auto_param=secret_auto_param,
             system_identity_param=system_identity_param,
             user_identity_param=user_identity_param,
+            workload_identity_param=workload_identity_param,
             service_principal_param=service_principal_param,
             source_params=source_params,
             target_params=target_params,
@@ -353,6 +397,7 @@ for source in SOURCE_RESOURCES:
             {secret_auto_param}
             {system_identity_param}
             {user_identity_param}
+            {workload_identity_param}
             {service_principal_param}
           examples:
             - name: Update the client type of a connection with resource name
@@ -368,6 +413,7 @@ for source in SOURCE_RESOURCES:
             secret_auto_param=secret_auto_param,
             system_identity_param=system_identity_param,
             user_identity_param=user_identity_param,
+            workload_identity_param=workload_identity_param,
             service_principal_param=service_principal_param,
             source_params=source_params,
             connection_id=connection_id,
