@@ -21,7 +21,7 @@ from ._resource_config import (
     TARGET_RESOURCES,
     AUTH_TYPE,
     RESOURCE,
-    OPT_OUT_OPTION,
+    OPT_OUT_OPTION
 )
 from ._validators import (
     get_source_resource_name,
@@ -38,7 +38,9 @@ from ._utils import (
     get_local_conn_auth_info,
     _get_azext_module,
     _get_or_add_extension,
-    springboot_migration_warning
+    springboot_migration_warning,
+    get_auth_type_for_update,
+    get_secret_type_for_update
 )
 from ._credential_free import is_passwordless_command
 # pylint: disable=unused-argument,unsubscriptable-object,unsupported-membership-test,too-many-statements,too-many-locals
@@ -289,8 +291,10 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                       target_resource_group=None, target_id=None,
                       secret_auth_info=None, secret_auth_info_auto=None,
                       user_identity_auth_info=None, system_identity_auth_info=None,
+                      workload_identity_auth_info=None,                     # only used as arg
                       service_principal_auth_info_secret=None,
                       key_vault_id=None,
+                      app_config_id=None,                                    # configuration store
                       service_endpoint=None,
                       private_endpoint=None,
                       store_in_connection_string=False,
@@ -310,10 +314,14 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                       signalr=None,                                          # Resource.SignalR
                       appinsights=None,                                      # Resource.AppInsights
                       ):
-
+    auth_action = 'optOutAllAuth' if (opt_out_list is not None and
+                                      OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list) else None
+    config_action = 'optOut' if (opt_out_list is not None and
+                                 OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list) else None
     auth_info = get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto, user_identity_auth_info,
-                                         system_identity_auth_info, service_principal_auth_info_secret, new_addon)
-    if is_passwordless_command(cmd, auth_info):
+                                         system_identity_auth_info, service_principal_auth_info_secret, new_addon,
+                                         auth_action, config_action)
+    if auth_info is not None and is_passwordless_command(cmd, auth_info) and auth_action != 'optOutAllAuth':
         if _get_or_add_extension(cmd, PASSWORDLESS_EXTENSION_NAME, PASSWORDLESS_EXTENSION_MODULE, False):
             azext_custom = _get_azext_module(
                 PASSWORDLESS_EXTENSION_NAME, PASSWORDLESS_EXTENSION_MODULE)
@@ -330,7 +338,8 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                                                       new_addon, no_wait,
                                                       cluster, scope, enable_csi,
                                                       customized_keys=customized_keys,
-                                                      opt_out_list=opt_out_list)
+                                                      opt_out_list=opt_out_list,
+                                                      app_config_id=app_config_id)
         raise CLIInternalError("Fail to install `serviceconnector-passwordless` extension. Please manually install it"
                                " with `az extension add --name serviceconnector-passwordless --upgrade`"
                                " and rerun the command")
@@ -349,6 +358,7 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                                   cluster, scope, enable_csi,
                                   customized_keys=customized_keys,
                                   opt_out_list=opt_out_list,
+                                  app_config_id=app_config_id
                                   )
 
 
@@ -380,6 +390,7 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
                            enable_mi_for_db_linker=None,
                            customized_keys=None,
                            opt_out_list=None,
+                           app_config_id=None,
                            **kwargs,
                            ):
     if not source_id:
@@ -387,8 +398,13 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
     if not new_addon and not target_id:
         raise RequiredArgumentMissingError(err_msg.format('--target-id'))
 
+    auth_action = 'optOutAllAuth' if (opt_out_list is not None and
+                                      OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list) else None
+    config_action = 'optOut' if (opt_out_list is not None and
+                                 OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list) else None
     auth_info = get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto, user_identity_auth_info,
-                                         system_identity_auth_info, service_principal_auth_info_secret, new_addon)
+                                         system_identity_auth_info, service_principal_auth_info_secret, new_addon,
+                                         auth_action, config_action)
 
     if store_in_connection_string:
         if client_type == CLIENT_TYPE.Dotnet.value:
@@ -396,8 +412,6 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
         else:
             logger.warning('client_type is not dotnet, ignore "--config-connstr"')
 
-    config_action = 'optOut' if (opt_out_list is not None and
-                                 OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list) else None
     public_network_action = 'optOut' if (opt_out_list is not None and
                                          OPT_OUT_OPTION.PUBLIC_NETWORK.value in opt_out_list) else None
 
@@ -414,6 +428,9 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
         'scope': scope,
         'configurationInfo': {
             'customizedKeys': customized_keys,
+            'configurationStore': {
+                'appConfigurationId': app_config_id,
+            },
             'action': config_action
         },
         'publicNetworkSolution': {
@@ -430,10 +447,14 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
         client = set_user_token_header(client, cmd.cli_ctx)
         from ._utils import create_key_vault_reference_connection_if_not_exist
         create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id, scope)
-    elif auth_info['auth_type'] == 'secret' and 'secret_info' in auth_info \
+    elif auth_info is not None and auth_info['auth_type'] == 'secret' and 'secret_info' in auth_info \
             and auth_info['secret_info']['secret_type'] == 'keyVaultSecretReference':
         raise ValidationError('--vault-id must be provided to use secret-name')
 
+    if app_config_id:
+        from ._utils import create_app_config_connection_if_not_exist
+        create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id, scope)
+
     if service_endpoint:
         client = set_user_token_header(client, cmd.cli_ctx)
         parameters['v_net_solution'] = {
@@ -473,7 +494,7 @@ def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-m
                                      'manually and then create the connection.'.format(str(e)))
 
     validate_service_state(parameters)
-    if enable_mi_for_db_linker:
+    if enable_mi_for_db_linker and auth_action != 'optOutAllAuth':
         new_auth_info = enable_mi_for_db_linker(
             cmd, source_id, target_id, auth_info, client_type, connection_name)
         parameters['auth_info'] = new_auth_info or parameters['auth_info']
@@ -614,8 +635,10 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
                       source_resource_group=None, source_id=None, indentifier=None,
                       secret_auth_info=None, secret_auth_info_auto=None,
                       user_identity_auth_info=None, system_identity_auth_info=None,
+                      workload_identity_auth_info=None,
                       service_principal_auth_info_secret=None,
                       key_vault_id=None,
+                      app_config_id=None,
                       service_endpoint=None,
                       private_endpoint=None,
                       store_in_connection_string=False,
@@ -649,7 +672,8 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
     if len(all_auth_info) == 1:
         auth_info = all_auth_info[0]
     # when user doesn't provide auth info and linker is not secret-with-username type
-    elif not all_auth_info and (linker.get('authInfo').get('authType') != 'secret' or
+    elif not all_auth_info and (linker.get('authInfo') is None or
+                                linker.get('authInfo').get('authType') != 'secret' or
                                 not linker.get('authInfo').get('name')):
         auth_info = linker.get('authInfo')
     else:
@@ -659,6 +683,9 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
     if client_type is None and not all_auth_info:
         raise ValidationError(
             'Either client type or auth info should be specified to update')
+    auth_action = 'optOutAllAuth' if (opt_out_list is not None and
+                                      OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list) else None
+    auth_info["auth_mode"] = auth_action
 
     if linker.get('secretStore') and linker.get('secretStore').get('keyVaultId'):
         key_vault_id = key_vault_id or linker.get('secretStore').get('keyVaultId')
@@ -689,6 +716,9 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
         'scope': scope or linker.get('scope'),
         'configurationInfo': {
             'customizedKeys': customized_keys,
+            'configurationStore': {
+                'appConfigurationId': app_config_id
+            },
             'action': config_action
         },
         'publicNetworkSolution': {
@@ -705,10 +735,14 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
         client = set_user_token_header(client, cmd.cli_ctx)
         from ._utils import create_key_vault_reference_connection_if_not_exist
         create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id, scope)
-    elif auth_info['auth_type'] == 'secret' and 'secret_info' in auth_info \
-            and auth_info['secret_info']['secret_type'] == 'keyVaultSecretReference':
+    elif get_auth_type_for_update(auth_info) == 'secret' and \
+            get_secret_type_for_update(auth_info) == 'keyVaultSecretReference':
         raise ValidationError('--vault-id must be provided to use secret-name')
 
+    if app_config_id:
+        from ._utils import create_app_config_connection_if_not_exist
+        create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id, scope)
+
     parameters['v_net_solution'] = linker.get('vNetSolution')
     if service_endpoint:
         parameters['v_net_solution'] = {
@@ -725,8 +759,8 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals, too-many-
 
     # migration warning for Spring Azure Cloud
     if client_type == CLIENT_TYPE.SpringBoot.value and target_type == RESOURCE.CosmosSql:
-        isSecretType = (auth_info['auth_type'] == AUTH_TYPE.SecretAuto.value or
-                        auth_info['auth_type'] == AUTH_TYPE.Secret.value)
+        isSecretType = (get_auth_type_for_update(auth_info) == AUTH_TYPE.SecretAuto.value or
+                        get_auth_type_for_update(auth_info) == AUTH_TYPE.Secret.value)
         logger.warning(springboot_migration_warning(require_update=False,
                                                     check_version=(not isSecretType),
                                                     both_version=isSecretType))
@@ -1013,6 +1047,7 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
                             schema_key,
                             schema_secret,
                             key_vault_id=None,
+                            app_config_id=None,
                             connection_name=None,
                             client_type=None,
                             source_resource_group=None,
@@ -1036,10 +1071,15 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
         from ._utils import create_key_vault_reference_connection_if_not_exist
         create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id)
 
+    if app_config_id:
+        from ._utils import create_app_config_connection_if_not_exist
+        create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id, scope)
     config_action = 'optOut' if (opt_out_list is not None and
                                  OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list) else None
     public_network_action = 'optOut' if (opt_out_list is not None and
                                          OPT_OUT_OPTION.PUBLIC_NETWORK.value in opt_out_list) else None
+    auth_action = 'optOutAllAuth' if (opt_out_list is not None and
+                                      OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list) else None
 
     # create bootstrap-server
     parameters = {
@@ -1053,7 +1093,8 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
                 'secret_type': 'rawValue',
                 'value': kafka_secret
             },
-            'auth_type': 'secret'
+            'auth_type': 'secret',
+            'auth_mode': auth_action
         },
         'secret_store': {
             'key_vault_id': key_vault_id,
@@ -1062,6 +1103,9 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
         'scope': scope,
         'configurationInfo': {
             'customizedKeys': customized_keys,
+            'configurationStore': {
+                'appConfigurationId': app_config_id,
+            },
             'action': config_action
         },
         'publicNetworkSolution': {
@@ -1088,7 +1132,8 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
                 'secret_type': 'rawValue',
                 'value': schema_secret
             },
-            'auth_type': 'secret'
+            'auth_type': 'secret',
+            'auth_mode': auth_action
         },
         'secret_store': {
             'key_vault_id': key_vault_id,
@@ -1096,6 +1141,9 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
         'client_type': client_type,
         'scope': scope,
         'configurationInfo': {
+            'configurationStore': {
+                'appConfigurationId': app_config_id,
+            },
             'action': config_action
         }
     }
@@ -1122,6 +1170,7 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
                             schema_key=None,
                             schema_secret=None,
                             key_vault_id=None,
+                            app_config_id=None,
                             client_type=None,
                             source_resource_group=None,
                             source_id=None,
@@ -1136,6 +1185,8 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
                                  OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list) else None
     public_network_action = 'optOut' if (opt_out_list is not None and
                                          OPT_OUT_OPTION.PUBLIC_NETWORK.value in opt_out_list) else None
+    auth_action = 'optOutAllAuth' if (opt_out_list is not None and
+                                      OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list) else None
 
     # use the suffix to decide the connection type
     if connection_name.endswith('_schema'):  # the schema registry connection
@@ -1155,12 +1206,17 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
         if server_linker.get('configurationInfo') and server_linker.get('configurationInfo').get('customizedKeys'):
             customized_keys = customized_keys or server_linker.get('configurationInfo').get('customizedKeys')
 
+        if app_config_id:
+            from ._utils import create_app_config_connection_if_not_exist
+            create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id)
+
         parameters = {
             'targetService': server_linker.get('targetService'),
             'auth_info': {
                 'name': schema_key or server_linker.get('authInfo').get('name'),
                 'secret': schema_secret,
-                'auth_type': 'secret'
+                'auth_type': 'secret',
+                'auth_mode': auth_action
             },
             'secret_store': {
                 'key_vault_id': key_vault_id,
@@ -1170,6 +1226,9 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
             'scope': server_linker.get('scope'),
             'configurationInfo': {
                 'customizedKeys': customized_keys,
+                'configurationStore': {
+                    'appConfigurationId': app_config_id,
+                },
                 'action': config_action,
             },
         }
@@ -1195,12 +1254,17 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
         if schema_linker.get('configurationInfo') and schema_linker.get('configurationInfo').get('customizedKeys'):
             customized_keys = customized_keys or schema_linker.get('configurationInfo').get('customizedKeys')
 
+        if app_config_id:
+            from ._utils import create_app_config_connection_if_not_exist
+            create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id)
+
         parameters = {
             'targetService': schema_linker.get('targetService'),
             'auth_info': {
                 'name': kafka_key or schema_linker.get('authInfo').get('name'),
                 'secret': kafka_secret,
-                'auth_type': 'secret'
+                'auth_type': 'secret',
+                'auth_mode': auth_action
             },
             'secret_store': {
                 'key_vault_id': key_vault_id,
@@ -1208,6 +1272,9 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
             'client_type': client_type or schema_linker.get('clientType'),
             'configurationInfo': {
                 'customizedKeys': customized_keys,
+                'configurationStore': {
+                    'appConfigurationId': app_config_id,
+                },
                 'action': config_action
             },
             'publicNetworkSolution': {
